Method: ActiveMerchant::Billing::QuantumGateway#initialize
- Defined in:
- lib/active_merchant/billing/gateways/quantum.rb
#initialize(options = {}) ⇒ QuantumGateway
These are the options that can be used when creating a new Quantum Gateway object.
:login => Your Quantum Gateway Gateway ID
:password => Your Quantum Gateway Vault Key or Restrict Key
NOTE: For testing supply your test GatewayLogin and GatewayKey
:email_receipt => true if you want a receipt sent to the customer (false be default)
:merchant_receipt => true if you want to override receiving the merchant receipt
:ignore_avs => true ignore both AVS and CVV verification :ignore_cvv => true don’t want to use CVV so continue processing even if CVV would have failed
38 39 40 41 |
# File 'lib/active_merchant/billing/gateways/quantum.rb', line 38 def initialize( = {}) requires!(, :login, :password) super end |